==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/NamedClusterFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface NamedClusterFluent<A extends NamedClusterFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildCluster instead.
 * @return The buildable object.
 */
@Deprecated public Cluster getCluster();
    public Cluster buildCluster();
    public A withCluster(Cluster cluster);
    public Boolean hasCluster();
    public NamedClusterFluent.ClusterNested<A> withNewCluster();
    public NamedClusterFluent.ClusterNested<A> withNewClusterLike(Cluster item);
    public NamedClusterFluent.ClusterNested<A> editCluster();
    public NamedClusterFluent.ClusterNested<A> editOrNewCluster();
    public NamedClusterFluent.ClusterNested<A> editOrNewClusterLike(Cluster item);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    public interface ClusterNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ClusterFluent<NamedClusterFluent.ClusterNested<N>> {

            public N and();
            public N endCluster();    }


}

==> kubernetes-model-core-5.3.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/NamedClusterFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface NamedClusterFluent<A extends NamedClusterFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildCluster instead.
 * @return The buildable object.
 */
@Deprecated public Cluster getCluster();
    public Cluster buildCluster();
    public A withCluster(Cluster cluster);
    public Boolean hasCluster();
    public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> withNewCluster();
    public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> withNewClusterLike(Cluster item);
    public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> editCluster();
    public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> editOrNewCluster();
    public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> editOrNewClusterLike(Cluster item);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    public interface ClusterNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ClusterFluent<io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<N>> {

            public N and();
            public N endCluster();    }


}
